CoremailSession class

Result of a Coremail login flow.

Constructors

CoremailSession({required String account, String? webmailCookie})
Creates a Coremail session.
const

Properties

account String
The authenticated account identifier.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webmailCookie String?
Optional cookie header for an authenticated Webmail session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited