flutter_coremail library
Coremail mail, Web session, and account configuration clients.
Classes
- CoremailAccount
- Credentials and server settings for a Coremail mailbox.
- CoremailAppPassword
- An application password returned by Coremail Webmail.
- CoremailClient
- IMAP and SMTP client facade for a Coremail mailbox.
- CoremailEndpoint
- Host, port, and transport security settings for a Coremail service.
- CoremailLoginRequest
- Input for a password or SSO login flow.
- CoremailServerConfiguration
- IMAP, SMTP, POP3, and Webmail settings for a Coremail server.
- CoremailSession
- Result of a Coremail login flow.
- CoremailSsoAdapter
- Adapter implemented by applications that own the Coremail SSO flow.
- CoremailWebClient
- Minimal JSON-RPC adapter for private Coremail Web actions.
- CoremailWebSession
- A short-lived authenticated Coremail Web session.
Enums
- CoremailErrorKind
- Categories of errors raised by Coremail clients.
- CoremailLoginMethod
- Login mechanisms supported by the package's login model.
- CoremailTransportSecurity
- Transport security modes supported by Coremail endpoints.
Exceptions / Errors
- CoremailException
- Exception containing a categorized Coremail client failure.
- CoremailWebException
- Exception raised when a Coremail Webmail request fails.